@@ -17,60 +17,6 @@
 #define _GNU_SOURCE 1
 #define _POSIX_PTHREAD_SEMANTICS 1
 #define _TANDEM_SOURCE 1
-#define HAVE_LONG_LONG 1
-#define HAVE_OFF_T 1
-#define SIZEOF_INT 4
-#define SIZEOF_SHORT 2
-#define SIZEOF_LONG 8
-#define SIZEOF_LONG_LONG 8
-#define SIZEOF___INT64 0
-#define SIZEOF_OFF_T 8
-#define SIZEOF_VOIDP 8
-#define SIZEOF_FLOAT 4
-#define SIZEOF_DOUBLE 8
-#define SIZEOF_TIME_T 4
-#define PRI_LL_PREFIX "ll"
-#define rb_pid_t pid_t
-#define PIDT2NUM(v) INT2NUM(v)
-#define NUM2PIDT(v) NUM2INT(v)
-#define PRI_PIDT_PREFIX PRI_INT_PREFIX
-#define rb_uid_t uid_t
-#define UIDT2NUM(v) UINT2NUM(v)
-#define NUM2UIDT(v) NUM2UINT(v)
-#define PRI_UIDT_PREFIX PRI_INT_PREFIX
-#define rb_gid_t gid_t
-#define GIDT2NUM(v) UINT2NUM(v)
-#define NUM2GIDT(v) NUM2UINT(v)
-#define PRI_GIDT_PREFIX PRI_INT_PREFIX
-#define rb_time_t time_t
-#define TIMET2NUM(v) INT2NUM(v)
-#define NUM2TIMET(v) NUM2INT(v)
-#define PRI_TIMET_PREFIX PRI_INT_PREFIX
-#define rb_dev_t dev_t
-#define DEVT2NUM(v) INT2NUM(v)
-#define NUM2DEVT(v) NUM2INT(v)
-#define PRI_DEVT_PREFIX PRI_INT_PREFIX
-#define rb_mode_t mode_t
-#define MODET2NUM(v) UINT2NUM(v)
-#define NUM2MODET(v) NUM2UINT(v)
-#define PRI_MODET_PREFIX PRI_INT_PREFIX
-#define rb_rlim_t rlim_t
-#define RLIM2NUM(v) ULL2NUM(v)
-#define NUM2RLIM(v) NUM2ULL(v)
-#define PRI_RLIM_PREFIX PRI_LL_PREFIX
-#define HAVE_PROTOTYPES 1
-#define TOKEN_PASTE(x,y) x##y
-#define STRINGIZE(expr) STRINGIZE0(expr)
-#define HAVE_STDARG_PROTOTYPES 1
-#define HAVE_VA_ARGS_MACRO 1
-#define NORETURN(x) __attribute__ ((noreturn)) x
-#define DEPRECATED(x) __attribute__ ((deprecated)) x
-#define NOINLINE(x) __attribute__ ((noinline)) x
-#define RUBY_ALIAS_FUNCTION_TYPE(type, prot, name, args) type prot __attribute__((alias(#name)));
-#define RUBY_ALIAS_FUNCTION_VOID(prot, name, args) RUBY_ALIAS_FUNCTION_TYPE(void, prot, name, args)
-#define HAVE_GCC_ATOMIC_BUILTINS 1
-#define RUBY_FUNC_EXPORTED __attribute__ ((visibility("default"))) extern
-#define HAVE_DECL_SYS_NERR 1
 #define HAVE_DIRENT_H 1
 #define HAVE__BOOL 1
 #define HAVE_STDBOOL_H 1
@@ -97,6 +43,60 @@
 #define HAVE_LOCALE_H 1
 #define HAVE_TIME_H 1
 #define HAVE_SYS_SOCKET_H 1
+#define HAVE_LONG_LONG 1
+#define HAVE_OFF_T 1
+#define SIZEOF_INT 4
+#define SIZEOF_SHORT 2
+#define SIZEOF_LONG 8
+#define SIZEOF_LONG_LONG 8
+#define SIZEOF___INT64 0
+#define SIZEOF_OFF_T 8
+#define SIZEOF_VOIDP 8
+#define SIZEOF_FLOAT 4
+#define SIZEOF_DOUBLE 8
+#define SIZEOF_TIME_T 8
+#define PRI_LL_PREFIX "ll"
+#define rb_pid_t pid_t
+#define PIDT2NUM(v) INT2NUM(v)
+#define NUM2PIDT(v) NUM2INT(v)
+#define PRI_PIDT_PREFIX PRI_INT_PREFIX
+#define rb_uid_t uid_t
+#define UIDT2NUM(v) UINT2NUM(v)
+#define NUM2UIDT(v) NUM2UINT(v)
+#define PRI_UIDT_PREFIX PRI_INT_PREFIX
+#define rb_gid_t gid_t
+#define GIDT2NUM(v) UINT2NUM(v)
+#define NUM2GIDT(v) NUM2UINT(v)
+#define PRI_GIDT_PREFIX PRI_INT_PREFIX
+#define rb_time_t time_t
+#define TIMET2NUM(v) LL2NUM(v)
+#define NUM2TIMET(v) NUM2LL(v)
+#define PRI_TIMET_PREFIX PRI_LL_PREFIX
+#define rb_dev_t dev_t
+#define DEVT2NUM(v) INT2NUM(v)
+#define NUM2DEVT(v) NUM2INT(v)
+#define PRI_DEVT_PREFIX PRI_INT_PREFIX
+#define rb_mode_t mode_t
+#define MODET2NUM(v) UINT2NUM(v)
+#define NUM2MODET(v) NUM2UINT(v)
+#define PRI_MODET_PREFIX PRI_INT_PREFIX
+#define rb_rlim_t rlim_t
+#define RLIM2NUM(v) ULL2NUM(v)
+#define NUM2RLIM(v) NUM2ULL(v)
+#define PRI_RLIM_PREFIX PRI_LL_PREFIX
+#define HAVE_PROTOTYPES 1
+#define TOKEN_PASTE(x,y) x##y
+#define STRINGIZE(expr) STRINGIZE0(expr)
+#define HAVE_STDARG_PROTOTYPES 1
+#define HAVE_VA_ARGS_MACRO 1
+#define NORETURN(x) __attribute__ ((noreturn)) x
+#define DEPRECATED(x) __attribute__ ((deprecated)) x
+#define NOINLINE(x) __attribute__ ((noinline)) x
+#define RUBY_ALIAS_FUNCTION_TYPE(type, prot, name, args) type prot __attribute__((alias(#name)));
+#define RUBY_ALIAS_FUNCTION_VOID(prot, name, args) RUBY_ALIAS_FUNCTION_TYPE(void, prot, name, args)
+#define HAVE_GCC_SYNC_BUILTINS 1
+#define RUBY_FUNC_EXPORTED __attribute__ ((visibility("default"))) extern
+#define HAVE_DECL_SYS_NERR 1
 #define SIZEOF_SIZE_T 8
 #define SIZEOF_PTRDIFF_T 8
 #define PRI_SIZE_PREFIX "z"
@@ -118,6 +118,7 @@
 #define HAVE_STRUCT_STAT_ST_CTIM 1
 #define HAVE_STRUCT_STAT_ST_CTIMESPEC 1
 #define HAVE_STRUCT_STAT_ST_CTIMENSEC 1
+#define HAVE_STRUCT_TIMEVAL 1
 #define HAVE_STRUCT_TIMESPEC 1
 #define HAVE_STRUCT_TIMEZONE 1
 #define HAVE_CLOCKID_T 1
@@ -144,7 +145,7 @@
 #define SIZEOF_UINTPTR_T 8
 #define HAVE_SSIZE_T 1
 #define SIZEOF_SSIZE_T 8
-#define GC_MARK_STACKFRAME_WORD 19
+#define HEAP_ALIGN_LOG 13
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define HAVE_ALLOCA 1
@@ -193,12 +194,12 @@
 #define HAVE_READLINK 1
 #define HAVE_READDIR_R 1
 #define HAVE_FSYNC 1
+#define HAVE_FDATASYNC 1
 #define HAVE_FCHOWN 1
 #define HAVE_SETITIMER 1
 #define HAVE_SETEUID 1
 #define HAVE_SETREUID 1
 #define HAVE_SETRESUID 1
-#define HAVE_SETPROCTITLE 1
 #define HAVE_SOCKETPAIR 1
 #define HAVE_SETEGID 1
 #define HAVE_SETREGID 1
@@ -218,6 +219,7 @@
 #define HAVE_SETRLIMIT 1
 #define HAVE_SYSCONF 1
 #define HAVE_CLOSE 1
+#define HAVE_GETPWNAM_R 1
 #define HAVE_GETGRNAM_R 1
 #define HAVE_DLOPEN 1
 #define HAVE_SIGPROCMASK 1
@@ -225,6 +227,7 @@
 #define HAVE_SIGSETJMP 1
 #define HAVE__SETJMP 1
 #define HAVE__LONGJMP 1
+#define HAVE_GETSID 1
 #define HAVE_SETSID 1
 #define HAVE_TELLDIR 1
 #define HAVE_SEEKDIR 1
@@ -234,6 +237,7 @@
 #define HAVE_TANH 1
 #define HAVE_LOG2 1
 #define HAVE_ROUND 1
+#define HAVE_LLABS 1
 #define HAVE_SETUID 1
 #define HAVE_SETGID 1
 #define HAVE_DAEMON 1
@@ -245,10 +249,16 @@
 #define HAVE_CLOCK_GETTIME 1
 #define HAVE_GETTIMEOFDAY 1
 #define HAVE_POLL 1
+#define HAVE_PPOLL 1
 #define HAVE_PREAD 1
 #define HAVE_SHUTDOWN 1
 #define HAVE_SIGALTSTACK 1
 #define HAVE_DL_ITERATE_PHDR 1
+#define HAVE_DUP 1
+#define HAVE_DUP3 1
+#define HAVE_PIPE2 1
+#define HAVE_POSIX_MEMALIGN 1
+#define HAVE_IOCTL 1
 #define RUBY_SETJMP(env) _setjmp(env)
 #define RUBY_LONGJMP(env,val) _longjmp(env,val)
 #define RUBY_JMP_BUF jmp_buf
@@ -261,7 +271,7 @@
 #define RSHIFT(x,y) ((x)>>(int)(y))
 #define FILE_COUNT _r
 #define FILE_READPTR _p
-#define SIZEOF_STRUCT_STAT_ST_INO 4
+#define SIZEOF_STRUCT_STAT_ST_INO SIZEOF_LONG
 #define HAVE__SC_CLK_TCK 1
 #define STACK_GROW_DIRECTION -1
 #define _REENTRANT 1
@@ -272,15 +282,17 @@
 #define HAVE_PTHREAD_ATTR_SETINHERITSCHED 1
 #define HAVE_PTHREAD_ATTR_GETSTACK 1
 #define HAVE_PTHREAD_STACKSEG_NP 1
+#define HAVE_PTHREAD_COND_INIT 1
+#define HAVE_PTHREAD_CONDATTR_SETCLOCK 1
+#define HAVE_PTHREAD_CONDATTR_INIT 1
 #define HAVE_PTHREAD_SIGMASK 1
+#define HAVE_PTHREAD_ATTR_INIT 1
 #define USE_ELF 1
+#define HAVE_ELF_ABI_H 1
 #define DLEXT_MAXLEN 3
 #define DLEXT ".so"
+#define LIBDIR_BASENAME "lib"
 #define HAVE_PTHREAD_H 1
-#define RUBY_LIB_VERSION_STYLE 3	/* full */
+#define HAVE_MEMMEM 1
 #define RUBY_EXEC_PREFIX "/usr/local"
-#define RUBY_LIB_PREFIX RUBY_EXEC_PREFIX"/lib/ruby"
-#define RUBY_SITE_LIB RUBY_LIB_PREFIX"/site_ruby"
-#define RUBY_VENDOR_LIB RUBY_LIB_PREFIX"/vendor_ruby"
-#define RUBY_PLATFORM "alpha-openbsd"
 #endif /* INCLUDE_RUBY_CONFIG_H */
