@@ -17,6 +17,32 @@
 #define _GNU_SOURCE 1
 #define _POSIX_PTHREAD_SEMANTICS 1
 #define _TANDEM_SOURCE 1
+#define HAVE_DIRENT_H 1
+#define HAVE__BOOL 1
+#define HAVE_STDBOOL_H 1
+#define HAVE_SYS_WAIT_H 1
+#define HAVE_LIMITS_H 1
+#define HAVE_SYS_FILE_H 1
+#define HAVE_SYS_IOCTL_H 1
+#define HAVE_SYS_SYSCALL_H 1
+#define HAVE_FCNTL_H 1
+#define HAVE_SYS_FCNTL_H 1
+#define HAVE_SYS_SELECT_H 1
+#define HAVE_SYS_TIME_H 1
+#define HAVE_SYS_TIMES_H 1
+#define HAVE_SYS_PARAM_H 1
+#define HAVE_PWD_H 1
+#define HAVE_GRP_H 1
+#define HAVE_A_OUT_H 1
+#define HAVE_UTIME_H 1
+#define HAVE_SYS_RESOURCE_H 1
+#define HAVE_NETINET_IN_SYSTM_H 1
+#define HAVE_FLOAT_H 1
+#define HAVE_IEEEFP_H 1
+#define HAVE_LANGINFO_H 1
+#define HAVE_LOCALE_H 1
+#define HAVE_TIME_H 1
+#define HAVE_SYS_SOCKET_H 1
 #define WORDS_BIGENDIAN 1
 #define HAVE_LONG_LONG 1
 #define HAVE_OFF_T 1
@@ -71,32 +97,6 @@
 #define RUBY_ALIAS_FUNCTION_VOID(prot, name, args) RUBY_ALIAS_FUNCTION_TYPE(void, prot, name, args)
 #define RUBY_FUNC_EXPORTED __attribute__ ((visibility("default"))) extern
 #define HAVE_DECL_SYS_NERR 1
-#define HAVE_DIRENT_H 1
-#define HAVE__BOOL 1
-#define HAVE_STDBOOL_H 1
-#define HAVE_SYS_WAIT_H 1
-#define HAVE_LIMITS_H 1
-#define HAVE_SYS_FILE_H 1
-#define HAVE_SYS_IOCTL_H 1
-#define HAVE_SYS_SYSCALL_H 1
-#define HAVE_FCNTL_H 1
-#define HAVE_SYS_FCNTL_H 1
-#define HAVE_SYS_SELECT_H 1
-#define HAVE_SYS_TIME_H 1
-#define HAVE_SYS_TIMES_H 1
-#define HAVE_SYS_PARAM_H 1
-#define HAVE_PWD_H 1
-#define HAVE_GRP_H 1
-#define HAVE_A_OUT_H 1
-#define HAVE_UTIME_H 1
-#define HAVE_SYS_RESOURCE_H 1
-#define HAVE_NETINET_IN_SYSTM_H 1
-#define HAVE_FLOAT_H 1
-#define HAVE_IEEEFP_H 1
-#define HAVE_LANGINFO_H 1
-#define HAVE_LOCALE_H 1
-#define HAVE_TIME_H 1
-#define HAVE_SYS_SOCKET_H 1
 #define SIZEOF_SIZE_T 4
 #define SIZEOF_PTRDIFF_T 4
 #define PRI_SIZE_PREFIX "z"
@@ -145,6 +145,7 @@
 #define SIZEOF_UINTPTR_T 4
 #define HAVE_SSIZE_T 1
 #define SIZEOF_SSIZE_T 4
+#define HEAP_ALIGN_LOG 12
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define HAVE_ALLOCA 1
@@ -218,6 +219,7 @@
 #define HAVE_SETRLIMIT 1
 #define HAVE_SYSCONF 1
 #define HAVE_CLOSE 1
+#define HAVE_GETPWNAM_R 1
 #define HAVE_GETGRNAM_R 1
 #define HAVE_DLOPEN 1
 #define HAVE_SIGPROCMASK 1
@@ -225,6 +227,7 @@
 #define HAVE_SIGSETJMP 1
 #define HAVE__SETJMP 1
 #define HAVE__LONGJMP 1
+#define HAVE_GETSID 1
 #define HAVE_SETSID 1
 #define HAVE_TELLDIR 1
 #define HAVE_SEEKDIR 1
@@ -234,6 +237,7 @@
 #define HAVE_TANH 1
 #define HAVE_LOG2 1
 #define HAVE_ROUND 1
+#define HAVE_LLABS 1
 #define HAVE_SETUID 1
 #define HAVE_SETGID 1
 #define HAVE_DAEMON 1
@@ -250,17 +254,18 @@
 #define HAVE_SHUTDOWN 1
 #define HAVE_SIGALTSTACK 1
 #define HAVE_DL_ITERATE_PHDR 1
+#define HAVE_DUP 1
+#define HAVE_DUP3 1
+#define HAVE_PIPE2 1
+#define HAVE_POSIX_MEMALIGN 1
+#define HAVE_IOCTL 1
 #define RUBY_SETJMP(env) _setjmp(env)
 #define RUBY_LONGJMP(env,val) _longjmp(env,val)
 #define RUBY_JMP_BUF jmp_buf
 #define HAVE_STRUCT_TM_TM_ZONE 1
 #define HAVE_TM_ZONE 1
 #define HAVE_STRUCT_TM_TM_GMTOFF 1
-#define HAVE_DAYLIGHT 1
-#define HAVE_VAR_TIMEZONE 1
-#define TYPEOF_VAR_TIMEZONE long
 #define HAVE_TIMEZONE 1
-#define TIMEZONE_VOID 1
 #define NEGATIVE_TIME_T 1
 #define POSIX_SIGNAL 1
 #define RSHIFT(x,y) ((x)>>(int)(y))
@@ -277,17 +282,17 @@
 #define HAVE_PTHREAD_ATTR_SETINHERITSCHED 1
 #define HAVE_PTHREAD_ATTR_GETSTACK 1
 #define HAVE_PTHREAD_STACKSEG_NP 1
+#define HAVE_PTHREAD_COND_INIT 1
 #define HAVE_PTHREAD_CONDATTR_SETCLOCK 1
+#define HAVE_PTHREAD_CONDATTR_INIT 1
 #define HAVE_PTHREAD_SIGMASK 1
+#define HAVE_PTHREAD_ATTR_INIT 1
 #define USE_ELF 1
+#define HAVE_ELF_ABI_H 1
 #define DLEXT_MAXLEN 3
 #define DLEXT ".so"
 #define LIBDIR_BASENAME "lib"
 #define HAVE_PTHREAD_H 1
-#define RUBY_LIB_VERSION_STYLE 3	/* full */
+#define HAVE_MEMMEM 1
 #define RUBY_EXEC_PREFIX "/usr/local"
-#define RUBY_LIB_PREFIX RUBY_EXEC_PREFIX"/lib/ruby"
-#define RUBY_SITE_LIB RUBY_LIB_PREFIX"/site_ruby"
-#define RUBY_VENDOR_LIB RUBY_LIB_PREFIX"/vendor_ruby"
-#define RUBY_PLATFORM "hppa-openbsd"
 #endif /* INCLUDE_RUBY_CONFIG_H */
