@@ -256,6 +256,8 @@
 #define HAVE_SIGALTSTACK 1
 #define HAVE_DL_ITERATE_PHDR 1
 #define HAVE_DUP 1
+#define HAVE_DUP3 1
+#define HAVE_PIPE2 1
 #define HAVE_POSIX_MEMALIGN 1
 #define HAVE_IOCTL 1
 #define RUBY_SETJMP(env) _setjmp(env)
