@@ -3,45 +3,61 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION == "1.9.3" or
-    raise "ruby lib version (1.9.3) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION == "2.0.0" or
+    raise "ruby lib version (2.0.0) doesn't match executable version (#{RUBY_VERSION})"
 
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/1.9.1/alpha-openbsd")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.0/alpha-openbsd")
   DESTDIR = '' unless defined? DESTDIR
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
-  CONFIG["MAJOR"] = "1"
-  CONFIG["MINOR"] = "9"
-  CONFIG["TEENY"] = "1"
-  CONFIG["PATCHLEVEL"] = "0"
-  CONFIG["INSTALL"] = '/usr/bin/install -c -o root -g bin'
+  CONFIG["MAJOR"] = "2"
+  CONFIG["MINOR"] = "0"
+  CONFIG["TEENY"] = "0"
+  CONFIG["PATCHLEVEL"] = "598"
+  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-2.0.0-p598/bin/install -c '
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
-  CONFIG["ruby_install_name"] = "ruby19"
-  CONFIG["RUBY_INSTALL_NAME"] = "ruby19"
-  CONFIG["RUBY_SO_NAME"] = "ruby19"
+  CONFIG["ruby_install_name"] = "ruby20"
+  CONFIG["RUBY_INSTALL_NAME"] = "ruby20"
+  CONFIG["RUBY_SO_NAME"] = "ruby20"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-1.9.pc"
+  CONFIG["ruby_pc"] = "ruby-2.0.pc"
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " newline.c"
   CONFIG["USE_RUBYGEMS"] = "YES"
-  CONFIG["MANTYPE"] = "man"
-  CONFIG["NROFF"] = "/bin/false"
+  CONFIG["MANTYPE"] = "doc"
+  CONFIG["NROFF"] = ""
+  CONFIG["vendorarchhdrdir"] = "$(vendorhdrdir)/$(sitearch)"
+  CONFIG["sitearchhdrdir"] = "$(sitehdrdir)/$(sitearch)"
+  CONFIG["rubyarchhdrdir"] = "$(rubyhdrdir)/$(arch)"
   CONFIG["vendorhdrdir"] = "$(rubyhdrdir)/vendor_ruby"
   CONFIG["sitehdrdir"] = "$(rubyhdrdir)/site_ruby"
-  CONFIG["rubyhdrdir"] = "$(includedir)/$(RUBY_BASE_NAME)-$(ruby_version)"
+  CONFIG["rubyhdrdir"] = "$(includedir)/$(RUBY_VERSION_NAME)"
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--program-suffix=19' '--with-soname=ruby19' '--enable-pthread' '--enable-ipv6' '--disable-option-checking' '--with-tcl-include=/usr/local/include/tcl8.5' '--with-tk-include=/usr/local/include/tk8.5' '--with-X11-dir=/usr/X11R6' '--enable-shared' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXX=c++' 'CXXFLAGS=-O2 -pipe'"
+  CONFIG["configure_args"] = " '--program-suffix=20' '--with-soname=ruby20' '--with-ruby-version=minor' '--with-mantype=doc' '--enable-pthread' '--enable-ipv6' '--disable-option-checking' '--with-tcl-include=/usr/local/include/tcl8.5' '--with-tk-include=/usr/local/include/tk8.5' '--with-tcllib=tcl85' '--with-tklib=tk85' '--with-X11-dir=/usr/X11R6' '--enable-shared' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXX=c++' 'CXXFLAGS=-O2 -pipe'"
+  CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
+  CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
   CONFIG["vendordir"] = "$(rubylibprefix)/vendor_ruby"
+  CONFIG["sitearchdir"] = "$(sitelibdir)/$(sitearch)"
+  CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
-  CONFIG["ruby_version"] = "1.9.1"
+  CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
+  CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
+  CONFIG["ruby_version"] = "2.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "alpha-openbsd"
+  CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
+  CONFIG["archincludedir"] = "$(includedir)/$(arch)"
+  CONFIG["sitearchlibdir"] = "$(libdir)/$(sitearch)"
+  CONFIG["archlibdir"] = "$(libdir)/$(arch)"
   CONFIG["RI_BASE_NAME"] = "ri"
   CONFIG["ridir"] = "$(datarootdir)/$(RI_BASE_NAME)"
+  CONFIG["rubysitearchprefix"] = "$(rubylibprefix)/$(sitearch)"
+  CONFIG["rubyarchprefix"] = "$(rubylibprefix)/$(arch)"
   CONFIG["rubylibprefix"] = "$(libdir)/$(RUBY_BASE_NAME)"
   CONFIG["MAKEFILES"] = "Makefile"
+  CONFIG["PLATFORM_DIR"] = ""
   CONFIG["THREAD_MODEL"] = "pthread"
   CONFIG["SYMBOL_PREFIX"] = ""
   CONFIG["EXPORT_PREFIX"] = ""
@@ -63,21 +79,31 @@ module RbConfig
   CONFIG["rubyw_install_name"] = ""
   CONFIG["LIBRUBY_DLDFLAGS"] = ""
   CONFIG["LIBRUBY_LDSHARED"] = "$(CC) -shared $(CCDLFLAGS)"
-  CONFIG["warnflags"] = "-Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Werror=pointer-arith -Werror=write-strings -Werror=declaration-after-statement -Werror=implicit-function-declaration"
-  CONFIG["debugflags"] = "-g"
-  CONFIG["optflags"] = "-O3"
+  CONFIG["EXTDLDFLAGS"] = ""
+  CONFIG["EXTLDFLAGS"] = ""
+  CONFIG["strict_warnflags"] = "-ansi -std=iso9899:199409"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wunused-variable -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wimplicit-function-declaration"
+  CONFIG["debugflags"] = "-ggdb3"
+  CONFIG["optflags"] = "-O3 -fno-fast-math"
   CONFIG["cxxflags"] = " $(optflags) $(debugflags) $(warnflags)"
   CONFIG["cflags"] = " $(optflags) $(debugflags) $(warnflags)"
-  CONFIG["cppflags"] = "-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include"
+  CONFIG["cppflags"] = ""
   CONFIG["NULLCMD"] = ":"
+  CONFIG["DLNOBJ"] = "dln.o"
   CONFIG["INSTALLDOC"] = "all"
   CONFIG["CAPITARGET"] = "nodoc"
   CONFIG["RDOCTARGET"] = "rdoc"
+  CONFIG["DTRACE_GLOMMED_OBJ"] = ""
+  CONFIG["DTRACE_OBJ"] = ""
+  CONFIG["DTRACE_EXT"] = "dmyh"
   CONFIG["EXECUTABLE_EXTS"] = ""
   CONFIG["ARCHFILE"] = ""
   CONFIG["LIBRUBY_RELATIVE"] = "no"
   CONFIG["EXTOUT"] = ".ext"
+  CONFIG["RUNRUBY_COMMAND"] = "$(MINIRUBY) $(srcdir)/tool/runruby.rb --extout=$(EXTOUT) $(RUNRUBYOPT)"
   CONFIG["PREP"] = "miniruby$(EXEEXT)"
+  CONFIG["BTESTRUBY"] = "$(MINIRUBY)"
+  CONFIG["CROSS_COMPILING"] = "no"
   CONFIG["TEST_RUNNABLE"] = "yes"
   CONFIG["setup"] = "Setup"
   CONFIG["EXTSTATIC"] = ""
@@ -97,6 +123,8 @@ module RbConfig
   CONFIG["ARCH_FLAG"] = ""
   CONFIG["DLDFLAGS"] = ""
   CONFIG["ALLOCA"] = ""
+  CONFIG["codesign"] = ""
+  CONFIG["POSTLINK"] = ":"
   CONFIG["WERRORFLAG"] = "-Werror"
   CONFIG["CHDIR"] = "cd -P"
   CONFIG["RMALL"] = "rm -fr"
@@ -104,20 +132,22 @@ module RbConfig
   CONFIG["RMDIR"] = "rmdir"
   CONFIG["CP"] = "cp"
   CONFIG["RM"] = "rm -f"
-  CONFIG["PKG_CONFIG"] = ""
+  CONFIG["PKG_CONFIG"] = "pkg-config"
+  CONFIG["PYTHON"] = ""
   CONFIG["DOXYGEN"] = ""
   CONFIG["DOT"] = ""
+  CONFIG["DTRACE"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "install -c -o root -g bin -m 444"
-  CONFIG["INSTALL_SCRIPT"] = "install -c -o root -g bin -m 555"
-  CONFIG["INSTALL_PROGRAM"] = "install -c -s -o root -g bin -m 555"
+  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-2.0.0-p598/bin/install -c  -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-2.0.0-p598/bin/install -c  -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-2.0.0-p598/bin/install -c -s  -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
   CONFIG["DLLWRAP"] = ""
   CONFIG["WINDRES"] = ""
-  CONFIG["OBJCOPY"] = "objcopy"
+  CONFIG["OBJCOPY"] = ":"
   CONFIG["OBJDUMP"] = "objdump"
   CONFIG["ASFLAGS"] = ""
   CONFIG["AS"] = "as"
@@ -128,6 +158,7 @@ module RbConfig
   CONFIG["OUTFLAG"] = "-o "
   CONFIG["CPPOUTFILE"] = "-o conftest.i"
   CONFIG["GNU_LD"] = "yes"
+  CONFIG["LD"] = "ld"
   CONFIG["GCC"] = "yes"
   CONFIG["EGREP"] = "/usr/bin/egrep"
   CONFIG["GREP"] = "/usr/bin/grep"
@@ -136,26 +167,29 @@ module RbConfig
   CONFIG["CXX"] = "c++"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include $(DEFS) $(cppflags)"
-  CONFIG["LDFLAGS"] = "-L. -L/usr/local/lib -Wl,-E"
+  CONFIG["LDFLAGS"] = "-L. -L/usr/local/lib -fstack-protector -Wl,-E"
   CONFIG["CFLAGS"] = "-mieee -O2 -pipe -fPIC"
   CONFIG["CC"] = "cc"
-  CONFIG["target_os"] = "openbsd5.1"
+  CONFIG["NACL_SDK_VARIANT"] = ""
+  CONFIG["NACL_SDK_ROOT"] = ""
+  CONFIG["NACL_TOOLCHAIN"] = ""
+  CONFIG["target_os"] = "openbsd5.7"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "alpha"
-  CONFIG["target"] = "alpha-unknown-openbsd5.1"
-  CONFIG["host_os"] = "openbsd5.1"
+  CONFIG["target"] = "alpha-unknown-openbsd5.7"
+  CONFIG["host_os"] = "openbsd5.7"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "alpha"
-  CONFIG["host"] = "alpha-unknown-openbsd5.1"
+  CONFIG["host"] = "alpha-unknown-openbsd5.7"
+  CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd5.1"
+  CONFIG["build_os"] = "openbsd5.7"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "alpha"
-  CONFIG["build"] = "alpha-unknown-openbsd5.1"
-  CONFIG["RUBY_RELEASE_DATE"] = "2011-10-30"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "1.9.3"
-  CONFIG["BASERUBY"] = "echo executable host ruby is required.  use --with-baseruby option.; false"
+  CONFIG["build"] = "alpha-unknown-openbsd5.7"
+  CONFIG["RUBY_RELEASE_DATE"] = "2014-11-13"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.0.0"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = ""
   CONFIG["build_alias"] = ""
@@ -175,7 +209,7 @@ module RbConfig
   CONFIG["docdir"] = "$(datarootdir)/doc/$(PACKAGE)"
   CONFIG["oldincludedir"] = "/usr/include"
   CONFIG["includedir"] = "$(prefix)/include"
-  CONFIG["localstatedir"] = "$(prefix)/var"
+  CONFIG["localstatedir"] = "$(DESTDIR)/var"
   CONFIG["sharedstatedir"] = "$(prefix)/com"
   CONFIG["sysconfdir"] = "$(DESTDIR)/etc"
   CONFIG["datadir"] = "$(datarootdir)"
@@ -183,7 +217,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
-  CONFIG["program_transform_name"] = "s&$$&19&;s&^&&"
+  CONFIG["program_transform_name"] = "s&$$&20&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
@@ -193,12 +227,7 @@ module RbConfig
   CONFIG["PACKAGE_NAME"] = ""
   CONFIG["PATH_SEPARATOR"] = ":"
   CONFIG["SHELL"] = "/bin/sh"
-  CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
-  CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
-  CONFIG["sitearchdir"] = "$(sitelibdir)/$(sitearch)"
-  CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
-  CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
+  CONFIG["archdir"] = "$(rubyarchdir)"
   CONFIG["topdir"] = File.dirname(__FILE__)
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
@@ -234,3 +263,23 @@ module RbConfig
 end
 autoload :Config, "rbconfig/obsolete.rb" # compatibility for ruby-1.8.4 and older.
 CROSS_COMPILING = nil unless defined? CROSS_COMPILING
+install = '/usr/bin/install -c -o root -g bin'  
+c = RbConfig::CONFIG 
+m = RbConfig::MAKEFILE_CONFIG
+if v = ENV['BSD_INSTALL_SCRIPT']
+  m['INSTALL'] = c['INSTALL'] = v.sub('-m 755', '')
+  m['INSTALL_SCRIPT'] = c['INSTALL_SCRIPT'] = v
+else
+  m['INSTALL'] = c['INSTALL'] = "#{install}"
+  m['INSTALL_SCRIPT'] = c['INSTALL_SCRIPT'] = "#{install} -m 755"
+end
+if v = ENV['BSD_INSTALL_PROGRAM']
+  m['INSTALL_PROGRAM'] = c['INSTALL_PROGRAM'] = v
+else
+  m['INSTALL_PROGRAM'] = c['INSTALL_PROGRAM'] = "#{install} -s -m 755"
+end
+if v = ENV['BSD_INSTALL_DATA']
+  m['INSTALL_DATA'] = c['INSTALL_DATA'] = v
+else
+  m['INSTALL_DATA'] = c['INSTALL_DATA'] = "#{install} -m 644"
+end
